@@ -58,18 +58,16 @@ summary(fit_num)$r.squared
 
 # same
 r_squared(y_num, pred_num)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
-          tweedie_p = 0)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
-          tweedie_p = 1.5)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 0)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 1.5)
 
 # weighted
 r_squared(y_num, pred_num, w = weights)
 r_squared(y_num, pred_num, w = weights, deviance_function = deviance_gamma) 
-r_squared(y_num, pred_num, w = weights, deviance_function = deviance_tweedie, 
-          tweedie_p = 2)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
-          tweedie_p = 1.5)
+r_squared(
+  y_num, pred_num, w = weights, deviance_function = deviance_tweedie, tweedie_p = 2
+)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 1.5)
 
 # respect to 'own' deviance formula
 myTweedie <- function(actual, predicted, w = NULL, ...) {
@@ -77,63 +75,20 @@ myTweedie <- function(actual, predicted, w = NULL, ...) {
 }
 r_squared(y_num, pred_num, deviance_function = myTweedie)
 
-## -----------------------------------------------------------------------------
-require(dplyr)
-
-# Regression with `Sepal.Length` as response
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  performance("Sepal.Length", "pred")
-
-# Same
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  performance("Sepal.Length", "pred", metrics = rmse)
-
-# Grouped by Species
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  group_by(Species) %>% 
-  do(performance(., actual = "Sepal.Length", predicted = "pred"))
-
-# Customized output
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  performance("Sepal.Length", "pred", value = "performance",
-              metrics = list(`root-mean-squared error` = rmse))
-
-# Multiple measures
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  performance("Sepal.Length", "pred",
-              metrics = list(rmse = rmse, mae = mae, `R-squared` = r_squared))
-
-# Grouped by Species
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  group_by(Species) %>% 
-  do(performance(., "Sepal.Length", "pred",
-                 metrics = list(rmse = rmse, 
-                                mae = mae, 
-                                `R-squared` = r_squared)))
-
-# Passing extra argument (Tweedie p)
-iris %>% 
-  mutate(pred = predict(fit_num, data = .)) %>% 
-  performance("Sepal.Length", "pred",
-              metrics = list(`normal deviance` = deviance_normal, 
-                             `Tweedie with p = 0` = deviance_tweedie),
-              tweedie_p = 0)
-
-
 ## -----------------------------------------------------------------------------
 ir <- iris
 ir$pred <- predict(fit_num, data = ir)
 
 # Create multiple Tweedie deviance functions
 multi_Tweedie <- multi_metric(deviance_tweedie, tweedie_p = c(0, seq(1, 3, by = 0.2)))
-perf <- performance(ir, actual = "Sepal.Length", predicted = "pred", 
-                    metrics = multi_Tweedie, key = "Tweedie p", value = "deviance")
+perf <- performance(
+  ir, 
+  actual = "Sepal.Length", 
+  predicted = "pred",
+  metrics = multi_Tweedie, 
+  key = "Tweedie p", 
+  value = "deviance"
+)
 perf$`Tweedie p` <- as.numeric(as.character(perf$`Tweedie p`))
 head(perf)
 
@@ -141,10 +96,17 @@ head(perf)
 plot(deviance ~ `Tweedie p`, data = perf, type = "s")
 
 # Same for Pseudo-R-Squared regarding Tweedie deviance
-multi_Tweedie_r2 <- multi_metric(r_squared, deviance_function = deviance_tweedie, 
-                                 tweedie_p = c(0, seq(1, 3, by = 0.2)))
-perf <- performance(ir, actual = "Sepal.Length", predicted = "pred", 
-                    metrics = multi_Tweedie_r2, key = "Tweedie p", value = "R-squared")
+multi_Tweedie_r2 <- multi_metric(
+  r_squared, deviance_function = deviance_tweedie, tweedie_p = c(0, seq(1, 3, by = 0.2))
+)
+perf <- performance(
+  ir, 
+  actual = "Sepal.Length", 
+  predicted = "pred", 
+  metrics = multi_Tweedie_r2, 
+  key = "Tweedie p", 
+  value = "R-squared"
+)
 perf$`Tweedie p` <- as.numeric(as.character(perf$`Tweedie p`))
 
 # Values vs. p
